Export Package VRC : bcB40Nc4cnt0
Update compared VRC:   B40Nc4ca20
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
dbccom.bpid                         B40Nc4cnt0
pbcdllfbcttf001                     B40Nc4cnt0 (without source)
pbcdllfbcttf002                     B40Nc4cnt0 (without source)
pbcdllfcisli120                     B40Nc4cnt0 (without source)
pbcdllfcisli200                     B40Nc4cnt0 (without source)
pbcdllfcisli201                     B40Nc4cnt0 (without source)
pbcdllfcpdsp200                     B40Nc4cnt0 (without source)
pbcdllffmfmd050                     B40Nc4cnt0 (without source)
pbcdllffmfmd055                     B40Nc4cnt0 (without source)
pbcdllffmfmd100                     B40Nc4cnt0 (without source)
pbcdllffmfoc000                     B40Nc4cnt0 (without source)
pbcdllffmfoc151                     B40Nc4cnt0 (without source)
pbcdllffmlbd050                     B40Nc4cnt0 (without source)
pbcdllfqmptc230                     B40Nc4cnt0 (without source)
pbcdllftccom000                     B40Nc4cnt0 (without source)
pbcdllftccom136                     B40Nc4cnt0 (without source)
pbcdllftccom700                     B40Nc4cnt0 (without source)
pbcdllftccom998                     B40Nc4cnt0 (without source)
pbcdllftcmcs002                     B40Nc4cnt0 (without source)
pbcdllftcmcs032                     B40Nc4cnt0 (without source)
pbcdllftcmcs033                     B40Nc4cnt0 (without source)
pbcdllftcmcs055                     B40Nc4cnt0 (without source)
pbcdllftctax000                     B40Nc4cnt0 (without source)
pbcdllftctax400                     B40Nc4cnt0 (without source)
pbcdllftdcms010                     B40Nc4cnt0 (without source)
pbcdllftdcms035                     B40Nc4cnt0 (without source)
pbcdllftdcms050                     B40Nc4cnt0 (without source)
pbcdllftdcms051                     B40Nc4cnt0 (without source)
pbcdllftdcms060                     B40Nc4cnt0 (without source)
pbcdllftdcms100                     B40Nc4cnt0 (without source)
pbcdllftdisa010                     B40Nc4cnt0 (without source)
pbcdllftdpcg000                     B40Nc4cnt0 (without source)
pbcdllftdpur000                     B40Nc4cnt0 (without source)
pbcdllftdpur043                     B40Nc4cnt0 (without source)
pbcdllftdpur300                     B40Nc4cnt0 (without source)
pbcdllftdpur301                     B40Nc4cnt0 (without source)
pbcdllftdpur350                     B40Nc4cnt0 (without source)
pbcdllftdpur351                     B40Nc4cnt0 (without source)
pbcdllftdpur400                     B40Nc4cnt0 (without source)
pbcdllftdpur450                     B40Nc4cnt0 (without source)
pbcdllftdpur451                     B40Nc4cnt0 (without source)
pbcdllftdsls000                     B40Nc4cnt0 (without source)
pbcdllftdsls039                     B40Nc4cnt0 (without source)
pbcdllftdsls100                     B40Nc4cnt0 (without source)
pbcdllftdsls101                     B40Nc4cnt0 (without source)
pbcdllftdsls150                     B40Nc4cnt0 (without source)
pbcdllftdsls151                     B40Nc4cnt0 (without source)
pbcdllftdsls300                     B40Nc4cnt0 (without source)
pbcdllftdsls301                     B40Nc4cnt0 (without source)
pbcdllftdsls304                     B40Nc4cnt0 (without source)
pbcdllftdsls350                     B40Nc4cnt0 (without source)
pbcdllftdsls351                     B40Nc4cnt0 (without source)
pbcdllftdsls400                     B40Nc4cnt0 (without source)
pbcdllftdsls410                     B40Nc4cnt0 (without source)
pbcdllftdsls450                     B40Nc4cnt0 (without source)
pbcdllftdsls451                     B40Nc4cnt0 (without source)
pbcdllftdsta114                     B40Nc4cnt0 (without source)
pbcdllftfacp000                     B40Nc4cnt0 (without source)
pbcdllftfacp200                     B40Nc4cnt0 (without source)
pbcdllftfacr200                     B40Nc4cnt0 (without source)
pbcdllftfacr202                     B40Nc4cnt0 (without source)
pbcdllftfacr303                     B40Nc4cnt0 (without source)
pbcdllftfcat000                     B40Nc4cnt0 (without source)
pbcdllftfcat004                     B40Nc4cnt0 (without source)
pbcdllftfcat210                     B40Nc4cnt0 (without source)
pbcdllftfcat211                     B40Nc4cnt0 (without source)
pbcdllftfcat220                     B40Nc4cnt0 (without source)
pbcdllftfcat221                     B40Nc4cnt0 (without source)
pbcdllftfcat240                     B40Nc4cnt0 (without source)
pbcdllftfcat400                     B40Nc4cnt0 (without source)
pbcdllftfcat412                     B40Nc4cnt0 (without source)
pbcdllftfcmg000                     B40Nc4cnt0 (without source)
pbcdllftfcmg003                     B40Nc4cnt0 (without source)
pbcdllftfcmg011                     B40Nc4cnt0 (without source)
pbcdllftfcmg101                     B40Nc4cnt0 (without source)
pbcdllftfcmg102                     B40Nc4cnt0 (without source)
pbcdllftfcmg103                     B40Nc4cnt0 (without source)
pbcdllftfcmg104                     B40Nc4cnt0 (without source)
pbcdllftfcmg111                     B40Nc4cnt0 (without source)
pbcdllftfcmg204                     B40Nc4cnt0 (without source)
pbcdllftfcmg401                     B40Nc4cnt0 (without source)
pbcdllftfcmg501                     B40Nc4cnt0 (without source)
pbcdllftfcmg502                     B40Nc4cnt0 (without source)
pbcdllftfcmg503                     B40Nc4cnt0 (without source)
pbcdllftffam000                     B40Nc4cnt0 (without source)
pbcdllftffam100                     B40Nc4cnt0 (without source)
pbcdllftffam110                     B40Nc4cnt0 (without source)
pbcdllftffbs000                     B40Nc4cnt0 (without source)
pbcdllftffbs003                     B40Nc4cnt0 (without source)
pbcdllftffbs005                     B40Nc4cnt0 (without source)
pbcdllftffbs010                     B40Nc4cnt0 (without source)
pbcdllftffbs011                     B40Nc4cnt0 (without source)
pbcdllftffbs012                     B40Nc4cnt0 (without source)
pbcdllftffbs020                     B40Nc4cnt0 (without source)
pbcdllftffbs021                     B40Nc4cnt0 (without source)
pbcdllftffbs030                     B40Nc4cnt0 (without source)
pbcdllftffbs040                     B40Nc4cnt0 (without source)
pbcdllftffbs041                     B40Nc4cnt0 (without source)
pbcdllftffbs042                     B40Nc4cnt0 (without source)
pbcdllftffbs110                     B40Nc4cnt0 (without source)
pbcdllftffbs111                     B40Nc4cnt0 (without source)
pbcdllftffbs120                     B40Nc4cnt0 (without source)
pbcdllftffbs121                     B40Nc4cnt0 (without source)
pbcdllftffbs130                     B40Nc4cnt0 (without source)
pbcdllftffbs131                     B40Nc4cnt0 (without source)
pbcdllftfgld004                     B40Nc4cnt0 (without source)
pbcdllftfgld011                     B40Nc4cnt0 (without source)
pbcdllftfgld017                     B40Nc4cnt0 (without source)
pbcdllftfgld018                     B40Nc4cnt0 (without source)
pbcdllftfgld021                     B40Nc4cnt0 (without source)
pbcdllftfgld102                     B40Nc4cnt0 (without source)
pbcdllftfgld106                     B40Nc4cnt0 (without source)
pbcdllftfgld107                     B40Nc4cnt0 (without source)
pbcdllftfgld110                     B40Nc4cnt0 (without source)
pbcdllftfgld215                     B40Nc4cnt0 (without source)
pbcdllftfgld450                     B40Nc4cnt0 (without source)
pbcdllftfgld475                     B40Nc4cnt0 (without source)
pbcdllftibom010                     B40Nc4cnt0 (without source)
pbcdllfticpr000                     B40Nc4cnt0 (without source)
pbcdllfticpr110                     B40Nc4cnt0 (without source)
pbcdllfticpr150                     B40Nc4cnt0 (without source)
pbcdllfticpr220                     B40Nc4cnt0 (without source)
pbcdllfticpr320                     B40Nc4cnt0 (without source)
pbcdllfticst001                     B40Nc4cnt0 (without source)
pbcdllftiedm120                     B40Nc4cnt0 (without source)
pbcdllftipcs000                     B40Nc4cnt0 (without source)
pbcdllftipcs320                     B40Nc4cnt0 (without source)
pbcdllftipcs350                     B40Nc4cnt0 (without source)
pbcdllftipcs360                     B40Nc4cnt0 (without source)
pbcdllftirou101                     B40Nc4cnt0 (without source)
pbcdllftirou102                     B40Nc4cnt0 (without source)
pbcdllftisfc000                     B40Nc4cnt0 (without source)
pbcdllftisfc010                     B40Nc4cnt0 (without source)
pbcdllftppdm000                     B40Nc4cnt0 (without source)
pbcdllftppin010                     B40Nc4cnt0 (without source)
pbcdllftppin020                     B40Nc4cnt0 (without source)
pbcdllftpppc000                     B40Nc4cnt0 (without source)
pbcdllftpppc215                     B40Nc4cnt0 (without source)
pbcdllftpppc301                     B40Nc4cnt0 (without source)
pbcdllftpppc305                     B40Nc4cnt0 (without source)
pbcdllftppss000                     B40Nc4cnt0 (without source)
pbcdllftppss615                     B40Nc4cnt0 (without source)
pbcdllftscfg200                     B40Nc4cnt0 (without source)
pbcdllftsmdm030                     B40Nc4cnt0 (without source)
pbcdllfwhinh000                     B40Nc4cnt0 (without source)
pbcdllfwhinh010                     B40Nc4cnt0 (without source)
pbcdllfwhinh020                     B40Nc4cnt0 (without source)
pbcdllmcisli205                     B40Nc4cnt0 (without source)
pbcdllmcprpd100                     B40Nc4cnt0 (without source)
pbcdllmcprrp100                     B40Nc4cnt0 (without source)
pbcdllmfmfoc110                     B40Nc4cnt0 (without source)
pbcdllmfmfoc200                     B40Nc4cnt0 (without source)
pbcdllmtccom001                     B40Nc4cnt0 (without source)
pbcdllmtccom100                     B40Nc4cnt0 (without source)
pbcdllmtccom130                     B40Nc4cnt0 (without source)
pbcdllmtcibd001                     B40Nc4cnt0 (without source)
pbcdllmtcibd002                     B40Nc4cnt0 (without source)
pbcdllmtcmcs003                     B40Nc4cnt0 (without source)
pbcdllmtcmcs035                     B40Nc4cnt0 (without source)
pbcdllmtcmcs036                     B40Nc4cnt0 (without source)
pbcdllmtdpur100                     B40Nc4cnt0 (without source)
pbcdllmtdpur101                     B40Nc4cnt0 (without source)
pbcdllmtdpur150                     B40Nc4cnt0 (without source)
pbcdllmtdpur151                     B40Nc4cnt0 (without source)
pbcdllmtdpur401                     B40Nc4cnt0 (without source)
pbcdllmtdsls401                     B40Nc4cnt0 (without source)
pbcdllmtdsta000                     B40Nc4cnt0 (without source)
pbcdllmtdsta100                     B40Nc4cnt0 (without source)
pbcdllmtdsta110                     B40Nc4cnt0 (without source)
pbcdllmtdsta200                     B40Nc4cnt0 (without source)
pbcdllmtdsta250                     B40Nc4cnt0 (without source)
pbcdllmtfacp240                     B40Nc4cnt0 (without source)
pbcdllmtffam800                     B40Nc4cnt0 (without source)
pbcdllmtffbs100                     B40Nc4cnt0 (without source)
pbcdllmtfgld008                     B40Nc4cnt0 (without source)
pbcdllmticpr200                     B40Nc4cnt0 (without source)
pbcdllmticst002                     B40Nc4cnt0 (without source)
pbcdllmtppdm740                     B40Nc4cnt0 (without source)
pbcdllmtsctm300                     B40Nc4cnt0 (without source)
pbcdllmtssoc000                     B40Nc4cnt0 (without source)
pbcdllmtssoc200                     B40Nc4cnt0 (without source)
pbcdllmtssoc220                     B40Nc4cnt0 (without source)
pbcdllmtssoc850                     B40Nc4cnt0 (without source)
pbcdllmtssoc860                     B40Nc4cnt0 (without source)
pbcdllmwhinh200                     B40Nc4cnt0 (without source)
pbcdllmwhinh300                     B40Nc4cnt0 (without source)
pbcdllmwhinh500                     B40Nc4cnt0 (without source)
pbcdllmwhinh520                     B40Nc4cnt0 (without source)
pbcdllmwhinr110                     B40Nc4cnt0 (without source)
pbcdllmwhltc100                     B40Nc4cnt0 (without source)
pbcdllmwhltc300                     B40Nc4cnt0 (without source)
pbcdllmwhwmd215                     B40Nc4cnt0 (without source)
pbcdllmwhwmd300                     B40Nc4cnt0 (without source)
pbcintdll0006                       B40Nc4cnt0 (without source)
bbcswh0011                          B40Nc4cnt0 (with source)
obcdllfbcttf001                     B40Nc4cnt0
obcdllfbcttf002                     B40Nc4cnt0
obcdllfcisli120                     B40Nc4cnt0
obcdllfcisli200                     B40Nc4cnt0
obcdllfcisli201                     B40Nc4cnt0
obcdllfcpdsp200                     B40Nc4cnt0
obcdllffmfmd050                     B40Nc4cnt0
obcdllffmfmd055                     B40Nc4cnt0
obcdllffmfmd100                     B40Nc4cnt0
obcdllffmfoc000                     B40Nc4cnt0
obcdllffmfoc151                     B40Nc4cnt0
obcdllffmlbd050                     B40Nc4cnt0
obcdllfqmptc230                     B40Nc4cnt0
obcdllftccom000                     B40Nc4cnt0
obcdllftccom136                     B40Nc4cnt0
obcdllftccom700                     B40Nc4cnt0
obcdllftccom998                     B40Nc4cnt0
obcdllftcmcs002                     B40Nc4cnt0
obcdllftcmcs032                     B40Nc4cnt0
obcdllftcmcs033                     B40Nc4cnt0
obcdllftcmcs055                     B40Nc4cnt0
obcdllftctax000                     B40Nc4cnt0
obcdllftctax400                     B40Nc4cnt0
obcdllftdcms010                     B40Nc4cnt0
obcdllftdcms035                     B40Nc4cnt0
obcdllftdcms050                     B40Nc4cnt0
obcdllftdcms051                     B40Nc4cnt0
obcdllftdcms060                     B40Nc4cnt0
obcdllftdcms100                     B40Nc4cnt0
obcdllftdisa010                     B40Nc4cnt0
obcdllftdpcg000                     B40Nc4cnt0
obcdllftdpur000                     B40Nc4cnt0
obcdllftdpur043                     B40Nc4cnt0
obcdllftdpur300                     B40Nc4cnt0
obcdllftdpur301                     B40Nc4cnt0
obcdllftdpur350                     B40Nc4cnt0
obcdllftdpur351                     B40Nc4cnt0
obcdllftdpur400                     B40Nc4cnt0
obcdllftdpur450                     B40Nc4cnt0
obcdllftdpur451                     B40Nc4cnt0
obcdllftdsls000                     B40Nc4cnt0
obcdllftdsls039                     B40Nc4cnt0
obcdllftdsls100                     B40Nc4cnt0
obcdllftdsls101                     B40Nc4cnt0
obcdllftdsls150                     B40Nc4cnt0
obcdllftdsls151                     B40Nc4cnt0
obcdllftdsls300                     B40Nc4cnt0
obcdllftdsls301                     B40Nc4cnt0
obcdllftdsls304                     B40Nc4cnt0
obcdllftdsls350                     B40Nc4cnt0
obcdllftdsls351                     B40Nc4cnt0
obcdllftdsls400                     B40Nc4cnt0
obcdllftdsls410                     B40Nc4cnt0
obcdllftdsls450                     B40Nc4cnt0
obcdllftdsls451                     B40Nc4cnt0
obcdllftdsta114                     B40Nc4cnt0
obcdllftfacp000                     B40Nc4cnt0
obcdllftfacp200                     B40Nc4cnt0
obcdllftfacr200                     B40Nc4cnt0
obcdllftfacr202                     B40Nc4cnt0
obcdllftfacr303                     B40Nc4cnt0
obcdllftfcat000                     B40Nc4cnt0
obcdllftfcat004                     B40Nc4cnt0
obcdllftfcat210                     B40Nc4cnt0
obcdllftfcat211                     B40Nc4cnt0
obcdllftfcat220                     B40Nc4cnt0
obcdllftfcat221                     B40Nc4cnt0
obcdllftfcat240                     B40Nc4cnt0
obcdllftfcat400                     B40Nc4cnt0
obcdllftfcat412                     B40Nc4cnt0
obcdllftfcmg000                     B40Nc4cnt0
obcdllftfcmg003                     B40Nc4cnt0
obcdllftfcmg011                     B40Nc4cnt0
obcdllftfcmg101                     B40Nc4cnt0
obcdllftfcmg102                     B40Nc4cnt0
obcdllftfcmg103                     B40Nc4cnt0
obcdllftfcmg104                     B40Nc4cnt0
obcdllftfcmg111                     B40Nc4cnt0
obcdllftfcmg204                     B40Nc4cnt0
obcdllftfcmg401                     B40Nc4cnt0
obcdllftfcmg501                     B40Nc4cnt0
obcdllftfcmg502                     B40Nc4cnt0
obcdllftfcmg503                     B40Nc4cnt0
obcdllftffam000                     B40Nc4cnt0
obcdllftffam100                     B40Nc4cnt0
obcdllftffam110                     B40Nc4cnt0
obcdllftffbs000                     B40Nc4cnt0
obcdllftffbs003                     B40Nc4cnt0
obcdllftffbs005                     B40Nc4cnt0
obcdllftffbs010                     B40Nc4cnt0
obcdllftffbs011                     B40Nc4cnt0
obcdllftffbs012                     B40Nc4cnt0
obcdllftffbs020                     B40Nc4cnt0
obcdllftffbs021                     B40Nc4cnt0
obcdllftffbs030                     B40Nc4cnt0
obcdllftffbs040                     B40Nc4cnt0
obcdllftffbs041                     B40Nc4cnt0
obcdllftffbs042                     B40Nc4cnt0
obcdllftffbs110                     B40Nc4cnt0
obcdllftffbs111                     B40Nc4cnt0
obcdllftffbs120                     B40Nc4cnt0
obcdllftffbs121                     B40Nc4cnt0
obcdllftffbs130                     B40Nc4cnt0
obcdllftffbs131                     B40Nc4cnt0
obcdllftfgld004                     B40Nc4cnt0
obcdllftfgld011                     B40Nc4cnt0
obcdllftfgld017                     B40Nc4cnt0
obcdllftfgld018                     B40Nc4cnt0
obcdllftfgld021                     B40Nc4cnt0
obcdllftfgld102                     B40Nc4cnt0
obcdllftfgld106                     B40Nc4cnt0
obcdllftfgld107                     B40Nc4cnt0
obcdllftfgld110                     B40Nc4cnt0
obcdllftfgld215                     B40Nc4cnt0
obcdllftfgld450                     B40Nc4cnt0
obcdllftfgld475                     B40Nc4cnt0
obcdllftibom010                     B40Nc4cnt0
obcdllfticpr000                     B40Nc4cnt0
obcdllfticpr110                     B40Nc4cnt0
obcdllfticpr150                     B40Nc4cnt0
obcdllfticpr220                     B40Nc4cnt0
obcdllfticpr320                     B40Nc4cnt0
obcdllfticst001                     B40Nc4cnt0
obcdllftiedm120                     B40Nc4cnt0
obcdllftipcs000                     B40Nc4cnt0
obcdllftipcs320                     B40Nc4cnt0
obcdllftipcs350                     B40Nc4cnt0
obcdllftipcs360                     B40Nc4cnt0
obcdllftirou101                     B40Nc4cnt0
obcdllftirou102                     B40Nc4cnt0
obcdllftisfc000                     B40Nc4cnt0
obcdllftisfc010                     B40Nc4cnt0
obcdllftppdm000                     B40Nc4cnt0
obcdllftppin010                     B40Nc4cnt0
obcdllftppin020                     B40Nc4cnt0
obcdllftpppc000                     B40Nc4cnt0
obcdllftpppc215                     B40Nc4cnt0
obcdllftpppc301                     B40Nc4cnt0
obcdllftpppc305                     B40Nc4cnt0
obcdllftppss000                     B40Nc4cnt0
obcdllftppss615                     B40Nc4cnt0
obcdllftscfg200                     B40Nc4cnt0
obcdllftsmdm030                     B40Nc4cnt0
obcdllfwhinh000                     B40Nc4cnt0
obcdllfwhinh010                     B40Nc4cnt0
obcdllfwhinh020                     B40Nc4cnt0
obcdllmcisli205                     B40Nc4cnt0
obcdllmcprpd100                     B40Nc4cnt0
obcdllmcprrp100                     B40Nc4cnt0
obcdllmfmfoc110                     B40Nc4cnt0
obcdllmfmfoc200                     B40Nc4cnt0
obcdllmtccom001                     B40Nc4cnt0
obcdllmtccom100                     B40Nc4cnt0
obcdllmtccom130                     B40Nc4cnt0
obcdllmtcibd001                     B40Nc4cnt0
obcdllmtcibd002                     B40Nc4cnt0
obcdllmtcmcs003                     B40Nc4cnt0
obcdllmtcmcs035                     B40Nc4cnt0
obcdllmtcmcs036                     B40Nc4cnt0
obcdllmtdpur100                     B40Nc4cnt0
obcdllmtdpur101                     B40Nc4cnt0
obcdllmtdpur150                     B40Nc4cnt0
obcdllmtdpur151                     B40Nc4cnt0
obcdllmtdpur401                     B40Nc4cnt0
obcdllmtdsls401                     B40Nc4cnt0
obcdllmtdsta000                     B40Nc4cnt0
obcdllmtdsta100                     B40Nc4cnt0
obcdllmtdsta110                     B40Nc4cnt0
obcdllmtdsta200                     B40Nc4cnt0
obcdllmtdsta250                     B40Nc4cnt0
obcdllmtfacp240                     B40Nc4cnt0
obcdllmtffam800                     B40Nc4cnt0
obcdllmtffbs100                     B40Nc4cnt0
obcdllmtfgld008                     B40Nc4cnt0
obcdllmticpr200                     B40Nc4cnt0
obcdllmticst002                     B40Nc4cnt0
obcdllmtppdm740                     B40Nc4cnt0
obcdllmtsctm300                     B40Nc4cnt0
obcdllmtssoc000                     B40Nc4cnt0
obcdllmtssoc200                     B40Nc4cnt0
obcdllmtssoc220                     B40Nc4cnt0
obcdllmtssoc850                     B40Nc4cnt0
obcdllmtssoc860                     B40Nc4cnt0
obcdllmwhinh200                     B40Nc4cnt0
obcdllmwhinh300                     B40Nc4cnt0
obcdllmwhinh500                     B40Nc4cnt0
obcdllmwhinh520                     B40Nc4cnt0
obcdllmwhinr110                     B40Nc4cnt0
obcdllmwhltc100                     B40Nc4cnt0
obcdllmwhltc300                     B40Nc4cnt0
obcdllmwhwmd215                     B40Nc4cnt0
obcdllmwhwmd300                     B40Nc4cnt0
obcintdll0006                       B40Nc4cnt0
